# tree-sitter-epics-cmd

[![CI][ci]](https://github.com/minijackson/tree-sitter-epics-cmd/actions/workflows/ci.yml)
[![discord][discord]](https://discord.gg/w7nTvsVJhm)
[![matrix][matrix]](https://matrix.to/#/#tree-sitter-chat:matrix.org)
[![npm][npm]](https://www.npmjs.com/package/tree-sitter-epics-cmd)
[![crates][crates]](https://crates.io/crates/tree-sitter-epics-cmd)
[![pypi][pypi]](https://pypi.org/project/tree-sitter-epics-cmd/)

A Tree-sitter parser for EPICS cmd "IOC shell" files.

## References

- [EPICS's IOC Shell documentation](https://docs.epics-controls.org/en/latest/appdevguide/IOCShell.html)
- [EPICS's implementation in `iocsh.cpp`](https://github.com/epics-base/epics-base/blob/7.0/modules/libcom/src/iocsh/iocsh.cpp)

[ci]: https://img.shields.io/github/actions/workflow/status/minijackson/tree-sitter-epics-cmd/ci.yml?logo=github&label=CI
[discord]: https://img.shields.io/discord/1063097320771698699?logo=discord&label=discord
[matrix]: https://img.shields.io/matrix/tree-sitter-chat%3Amatrix.org?logo=matrix&label=matrix
[npm]: https://img.shields.io/npm/v/tree-sitter-epics-cmd?logo=npm
[crates]: https://img.shields.io/crates/v/tree-sitter-epics-cmd?logo=rust
[pypi]: https://img.shields.io/pypi/v/tree-sitter-epics-cmd?logo=pypi&logoColor=ffd242
